@@ -9,13 +9,14 @@ from amaascore.assets.fund import Fund
 class ExchangeTradedFund(Fund):
 
     def __init__(self, asset_manager_id, asset_id, nav=None, expense_ratio=None, net_assets=None,
-                 asset_issuer_id=None, asset_status='Active', description='',
+                 asset_issuer_id=None, asset_status='Active', description='', display_name='', roll_price=False,
                  country_id=None, venue_id=None, currency=None, creation_date=None,
                  links=None, references=None,
                  *args, **kwargs):
         super(ExchangeTradedFund, self).__init__(asset_manager_id=asset_manager_id, asset_id=asset_id,
                                                  asset_issuer_id=asset_issuer_id,
-                                                 asset_status=asset_status, description=description,
+                                                 asset_status=asset_status, roll_price=roll_price,
+                                                 display_name=display_name, description=description,
                                                  country_id=country_id, venue_id=venue_id,
                                                  creation_date=creation_date, fund_type='ETF',
                                                  net_assets=net_assets, nav=nav, expense_ratio=expense_ratio,
