@@ -12,11 +12,10 @@ type_check = str if sys.version_info >= (3, 0, 0) else (str, unicode)
 class ForeignExchangeBase(Asset):
     """ This class should never be instantiated """
 
-    def __init__(self, asset_id, asset_status, description, major, country_codes, display_name=None,
+    def __init__(self, asset_id, asset_status, description, country_codes, display_name=None,
                  asset_manager_id=0, *args, **kwargs):
         self.asset_class = 'ForeignExchange'
         self.country_codes = country_codes
-        self.major = major
         super(ForeignExchangeBase, self).__init__(asset_manager_id=asset_manager_id, asset_id=asset_id, fungible=True,
                                                   display_name=display_name or asset_id, roll_price=False,
                                                   asset_status=asset_status, description=description,
@@ -34,6 +33,31 @@ class ForeignExchangeBase(Asset):
     def get_currencies(self):
         return [self.base_currency(), self.counter_currency()]
 
+    @property
+    def country_codes(self):
+        return self._country_codes
+
+    @country_codes.setter
+    def country_codes(self, country_codes):
+        """
+
+        :param country_codes:
+        :return:
+        """
+        self._country_codes = country_codes
+
+class ForeignExchange(ForeignExchangeBase):
+    """
+    The underlying FX pair used in an FX spot/forward asset
+    """
+    def __init__(self, asset_id, asset_manager_id=0, asset_status='Active', country_codes=[], major=False,
+                 description='', *args, **kwargs):
+        self.major = major
+        super(ForeignExchange, self).__init__(asset_manager_id=asset_manager_id, asset_id=asset_id,
+                                              asset_status=asset_status, description=description,
+                                              country_codes=country_codes,
+                                              *args, **kwargs)
+
     @property
     def major(self):
         return self._major
@@ -50,53 +74,21 @@ class ForeignExchangeBase(Asset):
         else:
             self._major = False
 
-    @property
-    def country_codes(self):
-        return self._country_codes
 
-    @country_codes.setter
-    def country_codes(self, country_codes):
-        """
-
-        :param country_codes:
-        :return:
-        """
-        self._country_codes = country_codes
-
-class ForeignExchange(ForeignExchangeBase):
+class ForeignExchangeSpot(ForeignExchangeBase):
     """
-    A spot FX transaction.
-    """
-    def __init__(self, asset_id, asset_status='Active', country_codes=[], major=False, description='', *args, **kwargs):
-        super(ForeignExchange, self).__init__(asset_id=asset_id, asset_status=asset_status, description=description,
-                                              country_codes=country_codes, major=major,
-                                              *args, **kwargs)
-
-
-class ForeignExchangeForward(ForeignExchangeBase):
-    """
-    A forward-dated FX transaction.  If there is a fixing_date, it is an NDF.
+    Spot FX (Settles as soon as possible).
     """
 
-    def __init__(self, asset_id, asset_status='Active', description='', major=False, country_codes=[],
-                 forward_rate=None, underlying=None, settlement_date=None, fixing_date=None,
+    def __init__(self, asset_manager_id, asset_id, asset_status='Active', description='', country_codes=[],
+                 underlying=None, settlement_date=None,
                  display_name=None, *args, **kwargs):
-        self.forward_rate = forward_rate
         self.underlying = underlying
         self.settlement_date = settlement_date
-        self.fixing_date = fixing_date
-        super(ForeignExchangeForward, self).__init__(asset_id=asset_id, asset_status=asset_status,
-                                                     country_codes=country_codes, display_name=display_name,
-                                                     major=major, description=description, *args, **kwargs)
-
-    @property
-    def fixing_date(self):
-        return self._fixing_date
-
-    @fixing_date.setter
-    def fixing_date(self, fixing_date):
-        self._fixing_date = parse(fixing_date).date() if isinstance(fixing_date, type_check) \
-            else fixing_date
+        super(ForeignExchangeSpot, self).__init__(asset_manager_id=asset_manager_id, asset_id=asset_id,
+                                                  asset_status=asset_status,
+                                                  country_codes=country_codes, display_name=display_name,
+                                                  description=description, *args, **kwargs)
 
     @property
     def settlement_date(self):
@@ -106,4 +98,30 @@ class ForeignExchangeForward(ForeignExchangeBase):
     def settlement_date(self, settlement_date):
         self._settlement_date = parse(settlement_date).date() if isinstance(settlement_date, type_check) \
             else settlement_date
+
+
+class ForeignExchangeForward(ForeignExchangeSpot):
+    """
+    A forward-dated FX.  If there is a fixing_date, it is an NDF.
+    """
+
+    def __init__(self, asset_manager_id, asset_id, asset_status='Active', description='', country_codes=[],
+                 forward_rate=None, underlying=None, settlement_date=None, fixing_date=None,
+                 display_name=None, *args, **kwargs):
+        self.forward_rate = forward_rate
+        self.fixing_date = fixing_date
+        super(ForeignExchangeForward, self).__init__(asset_manager_id=asset_manager_id, asset_id=asset_id,
+                                                     asset_status=asset_status,
+                                                     underlying=underlying, settlement_date=settlement_date,
+                                                     country_codes=country_codes, display_name=display_name,
+                                                     description=description, *args, **kwargs)
+
+    @property
+    def fixing_date(self):
+        return self._fixing_date
+
+    @fixing_date.setter
+    def fixing_date(self, fixing_date):
+        self._fixing_date = parse(fixing_date).date() if isinstance(fixing_date, type_check) \
+            else fixing_date
         
\ No newline at end of file
