@@ -37,16 +37,29 @@ class AssetsInterface(Interface):
         url = '%s/assets/%s' % (self.endpoint, assets[0].asset_manager_id)
         json_body = [asset.to_interface() for asset in assets]
         response = self.session.post(url, json=json_body)
-
         if response.ok:
             self.logger.info('Successfully Created Assets - Asset Manager: %s', assets[0].asset_manager_id)
-            t = response.json()
             assets = [asset for asset in response.json()]
             return assets
         else:
             self.logger.error(response.text)
             response.raise_for_status()
 
+    def upsert(self, asset):
+        ''' upsert only support upserting one asset at a time'''
+        self.logger.info('Upsert Asset - Asset Manager: %s - Asset ID: %s', asset.asset_manager_id, asset.asset_id)
+        url = '%s/assets/%s/%s' % (self.endpoint, asset.asset_manager_id, asset.asset_id)
+        response = self.session.post(url, json=asset.to_interface(), params={'upsert': True})
+        if response.ok:
+            self.logger.info('Successfully Upserted Asset - Asset Manager: %s - Asset ID: %s', asset.asset_manager_id,
+                             asset.asset_id)
+            asset = json_to_asset(response.json())
+            return asset
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
+
+
     def amend(self, asset):
         self.logger.info('Amend Asset - Asset Manager: %s - Asset ID: %s', asset.asset_manager_id, asset.asset_id)
         url = '%s/assets/%s/%s' % (self.endpoint, asset.asset_manager_id, asset.asset_id)
@@ -100,13 +113,11 @@ class AssetsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
-    def search(self, asset_manager_ids=None, asset_ids=None, asset_classes=None, asset_types=None, 
+    def search(self, asset_manager_id, asset_ids=None, asset_classes=None, asset_types=None, 
                page_no=None, page_size=None):
-        self.logger.info('Search for Assets - Asset Manager(s): %s', asset_manager_ids)
+        self.logger.info('Search for Assets - Asset Manager: %s', asset_manager_id)
         search_params = {}
         # Potentially roll this into a loop through args rather than explicitly named - depends on additional validation
-        if asset_manager_ids:
-            search_params['asset_manager_ids'] = ','.join([str(amid) for amid in asset_manager_ids])
         if asset_ids:
             search_params['asset_ids'] = ','.join(asset_ids)
         if asset_classes:
@@ -117,7 +128,7 @@ class AssetsInterface(Interface):
             search_params['page_no'] = page_no
         if page_size:
             search_params['page_size'] = page_size
-        url = self.endpoint + '/assets'
+        url = '%s/assets/%s' % (self.endpoint, asset_manager_id)
         response = self.session.get(url, params=search_params)
         if response.ok:
             assets = [json_to_asset(json_asset) for json_asset in response.json()]
