@@ -9,7 +9,7 @@ from amaascore.core.amaas_model import AMaaSModel
 class Address(AMaaSModel):
 
     def __init__(self, line_one, city, country_id, address_primary, line_two=None, region=None, postal_code=None,
-                 active=True, version=1, *args, **kwargs):
+                 *args, **kwargs):
         self.address_primary = address_primary
         self.line_one = line_one
         self.line_two = line_two
@@ -17,8 +17,6 @@ class Address(AMaaSModel):
         self.region = region
         self.postal_code = postal_code
         self.country_id = country_id
-        self.active = active
-        self.version = version
         super(Address, self).__init__(*args, **kwargs)
 
     @property
@@ -36,11 +34,9 @@ class Address(AMaaSModel):
 
 class Email(AMaaSModel):
 
-    def __init__(self, email, email_primary, active=True, version=1, *args, **kwargs):
+    def __init__(self, email, email_primary, *args, **kwargs):
         self.email_primary = email_primary
         self.email = email
-        self.active = active
-        self.version = version
         super(Email, self).__init__(*args, **kwargs)
 
     @property
@@ -58,37 +54,6 @@ class Email(AMaaSModel):
 
 class Link(AMaaSModel):
 
-    def __init__(self, linked_party_id, active=True, version=1, *args, **kwargs):
+    def __init__(self, linked_party_id, *args, **kwargs):
         self.linked_party_id = linked_party_id
-        self.active = active
-        self.version = version
         super(Link, self).__init__(*args, **kwargs)
-
-class Reference(AMaaSModel):
-    
-    def __init__(self, reference_value, active=True, *args, **kwargs):
-        self.reference_value = reference_value
-        self.active = active
-        super(Reference, self).__init__(*args, **kwargs)
-
-
-class Comment(AMaaSModel):
-    """
-    A free text comment about the party
-    """
-    @staticmethod
-    def party_key():
-        return 'comment_type'
-
-    @staticmethod
-    def unique():
-        return True
-
-    @staticmethod
-    def table_name():
-        return 'party_comments'
-
-    def __init__(self, comment_value, active=True, *args, **kwargs):
-        self.comment_value = comment_value
-        self.active = active
-        super(Comment, self).__init__(*args, **kwargs)
\ No newline at end of file
