@@ -6,7 +6,7 @@ import json
 from amaascore.config import ENVIRONMENT
 from amaascore.core.amaas_model import json_handler
 from amaascore.core.interface import Interface
-from amaascore.transactions.utils import json_to_transaction, json_to_position
+from amaascore.transactions.utils import json_to_transaction, json_to_position, json_to_mtm_result
 
 
 class TransactionsInterface(Interface):
@@ -28,6 +28,28 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
+    def create_many(self, transactions):
+        if type(transactions) is not list:
+            raise ValueError('Error - create_many takes in a list of transactions instead of single transaction')
+        transactions_json = []        
+        # check to ensure all transactions have the same asset_manager_id
+        asset_manager_id = transactions[0].asset_manager_id
+        for transaction in transactions:
+            transactions_json.append(transaction.to_interface())
+            if transaction.asset_manager_id != asset_manager_id:
+                raise AttributeError('Check failed - Not all transactions have the same asset manager ID.')
+        self.logger.info('Multple new Transactions - Asset Manager: %s', asset_manager_id)
+        url = '%s/transactions/%s' % (self.endpoint, asset_manager_id)
+        response = self.session.post(url, json=transactions_json)
+        if response.ok:
+            transactions = []
+            for transaction_json in response.json():
+                transactions.append(json_to_transaction(transaction_json))
+            return transactions
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
+
     def amend(self, transaction):
         self.logger.info('Amend Transaction - Asset Manager: %s - Transaction ID: %s', transaction.asset_manager_id,
                          transaction.transaction_id)
@@ -89,16 +111,14 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
-    def search(self, asset_manager_ids=[], transaction_ids=[], transaction_statuses=[],
+    def search(self, asset_manager_id, transaction_ids=[], transaction_statuses=[],
                asset_book_ids=[], counterparty_book_ids=[], asset_ids=[], transaction_date_start=None,
                transaction_date_end=None, code_types=[], code_values=[], link_types=[], linked_transaction_ids=[],
                party_types=[], party_ids=[], reference_types=[], reference_values=[], client_ids=[],
                page_no=None, page_size=None):
-        self.logger.info('Search Transactions - Asset Manager(s): %s', asset_manager_ids)
+        self.logger.info('Search Transactions - Asset Manager: %s', asset_manager_id)
         search_params = {}
         # Potentially roll this into a loop through args rather than explicitly named - depends on additional validation
-        if asset_manager_ids:
-            search_params['asset_manager_ids'] = ','.join([str(amid) for amid in asset_manager_ids])
         if transaction_ids:
             search_params['transaction_ids'] = ','.join(transaction_ids)
         if transaction_statuses:
@@ -135,7 +155,7 @@ class TransactionsInterface(Interface):
             search_params['page_no'] = page_no
         if page_size:
             search_params['page_size'] = page_size
-        url = self.endpoint + '/transactions'
+        url = '%s/transactions/%s' % (self.endpoint, asset_manager_id)
         response = self.session.get(url, params=search_params)
         if response.ok:
             transactions = [json_to_transaction(json_transaction) for json_transaction in response.json()]
@@ -145,14 +165,63 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
-    def position_search(self, asset_manager_ids=None, book_ids=None, account_ids=None,
+    def new_mtm_result(self, asset_manager_id, mtm_results):
+        self.logger.info('Marking to market Positions - Asset Manager: %s', asset_manager_id)
+        if not isinstance(mtm_results, list):
+            mtm_results = [mtm_results]
+        mtm_result_json = []
+        for mtm_result in mtm_results:
+            mtm_result_json.append(mtm_result.to_interface())
+        url = '%s/mtm/%s' % (self.endpoint, asset_manager_id)
+        response = self.session.post(url, json=mtm_result_json)
+        if response.ok:
+            mtm_results = []
+            for mtm_result_json in response.json():
+                mtm_results.append(json_to_mtm_result(mtm_result_json))
+            return mtm_results
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
+
+    def amend_mtm_result(self, asset_manager_id, mtm_results):
+        self.logger.info('Amending mtm Positions - Asset Manager: %s', asset_manager_id)
+        if not isinstance(mtm_results, list):
+            mtm_results = [mtm_results]
+        mtm_result_json = []
+        for mtm_result in mtm_results:
+            mtm_result_json.append(mtm_result.to_interface())
+        url = '%s/mtm/%s' % (self.endpoint, asset_manager_id)
+        response = self.session.put(url, json=mtm_result_json)
+        if response.ok:
+            mtm_results = []
+            for mtm_result_json in response.json():
+                mtm_results.append(json_to_mtm_result(mtm_result_json))
+            return mtm_results
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
+
+    def retrieve_mtm_result(self, book_id, asset_manager_id, paramaters):
+        """
+        parameters is a dictionary of all the mtm result filter parameters
+        """
+        self.logger.info('Retrieving mtm Positions - Asset Manager: %s', asset_manager_id)
+        url = '%s/mtm/%s' % (self.endpoint, asset_manager_id)       
+        paramaters.update({'book_id': book_id})  
+        response = self.session.get(url, params = paramaters)
+        if response.ok:
+            mtm_results = [json_to_mtm_result(json_mtm_result) for json_mtm_result in response.json()]
+            self.logger.info('Returned %s mtm results.', len(mtm_results))
+            return mtm_results
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
+
+    def position_search(self, asset_manager_id, book_ids=None, account_ids=None,
                         accounting_types=['Transaction Date'], asset_ids=None, position_date=None):
-        self.logger.info('Search Positions - Asset Manager(s): %s', asset_manager_ids)
-        url = self.endpoint + '/positions'
+        self.logger.info('Search Positions - Asset Manager: %s', asset_manager_id)
         search_params = {}
         # Potentially roll into a loop
-        if asset_manager_ids:
-            search_params['asset_manager_ids'] = ','.join([str(amid) for amid in asset_manager_ids])
         if book_ids:
             search_params['book_ids'] = ','.join(book_ids)
         if account_ids:
@@ -163,6 +232,7 @@ class TransactionsInterface(Interface):
             search_params['asset_ids'] = ','.join(asset_ids)
         if position_date:
             search_params['position_date'] = position_date
+        url = '%s/positions/%s' % (self.endpoint, asset_manager_id)
         response = self.session.get(url, params=search_params)
         if response.ok:
             positions = [json_to_position(json_position) for json_position in response.json()]
@@ -364,4 +434,4 @@ class TransactionsInterface(Interface):
             return response.json()
         else:
             self.logger.error(response.text)
-            response.raise_for_status()
+            response.raise_for_status()
\ No newline at end of file
